<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>CreateFieldDialog</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1049"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1062"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1072"/>
        <source>String</source>
        <translation>Cadena Carácteres</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1073"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1074"/>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1075"/>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1076"/>
        <source>Phone Number</source>
        <translation>Número móvil</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1077"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1078"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1083"/>
        <source>Order</source>
        <translation>Orden</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="63"/>
        <source>Copy of </source>
        <translation>Copia de </translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="110"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="112"/>
        <location filename="../../DetailedWindow.cpp" line="739"/>
        <location filename="../../DetailedWindow.cpp" line="752"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="113"/>
        <source>Change Face Pict.</source>
        <translation>Cambiar imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="114"/>
        <source>Mirror Face Pict.</source>
        <translation>Girar imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="115"/>
        <source>Change Back Pict.</source>
        <translation>Cambiar reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="116"/>
        <source>Mirror Back Pict.</source>
        <translation>Girar reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="117"/>
        <source>Delete Face Pict.</source>
        <translation>Borrar imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="118"/>
        <source>Delete Back Pict.</source>
        <translation>Borrar reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="119"/>
        <source>Modify fields</source>
        <translation>Modificar campos</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="124"/>
        <source>New Card</source>
        <translation>Nueva tarjeta</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="125"/>
        <source>Edit Card</source>
        <translation>Modificar tarjeta</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="126"/>
        <source>New Card like this</source>
        <translation>Nueva tarjeta como esta</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="127"/>
        <source>Duplicate Card</source>
        <translation>Duplicar tarjeta</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="128"/>
        <source>Export Face Pict.</source>
        <translation>Extraer imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="129"/>
        <source>Export Back Pict.</source>
        <translation>Extraer reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="156"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="167"/>
        <source>Group Name</source>
        <translation>Nombre del grupo</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="185"/>
        <source>Membership Info</source>
        <translation>Información de asociación</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="186"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="187"/>
        <source>Credit Card</source>
        <translation>Targeta de crédito</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="188"/>
        <source>Bank Account</source>
        <translation>Cuenta bancaria</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="189"/>
        <source>Health Numbers</source>
        <translation>Número Seguridad social</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="190"/>
        <source>Passport Info</source>
        <translation>Pasaporte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="191"/>
        <source>Note Card</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="192"/>
        <source>Car Info</source>
        <translation>Coche</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="193"/>
        <source>Cellular Phone</source>
        <translation>Teléfono móbil</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="194"/>
        <source>Serial Number Software</source>
        <translation>Número de serie Software</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="195"/>
        <source>Serial Number Hardware</source>
        <translation>Número de serie Hardware</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="196"/>
        <source>Web site</source>
        <translation>Web</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="197"/>
        <source>ID Card</source>
        <translation>DNI</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="198"/>
        <source>Social Security Number</source>
        <translation>Seguridad social</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="199"/>
        <source>Email Account</source>
        <translation>Cuenta de correo</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="200"/>
        <source>Driver&apos;s License</source>
        <translation>Carnet de conducir</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="201"/>
        <source>Others</source>
        <translation>Otros</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="205"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="473"/>
        <location filename="../../DetailedWindow.cpp" line="519"/>
        <source>Click to see</source>
        <translation>Pulsa para ver</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="573"/>
        <source>Card description is missing</source>
        <translation>Tarjeta sin descripción</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="583"/>
        <source>Type card is missing</source>
        <translation>Tarjeta sin tipo</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="737"/>
        <location filename="../../DetailedWindow.cpp" line="750"/>
        <source>Edit</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="738"/>
        <location filename="../../DetailedWindow.cpp" line="751"/>
        <source>Mirror</source>
        <translation>Imagen espejo</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="742"/>
        <source>Export Face</source>
        <translation>Extraer imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="755"/>
        <source>Export Back</source>
        <translation>Extraer reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="773"/>
        <source>Choose card face image file</source>
        <translation>Elije una imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="775"/>
        <location filename="../../DetailedWindow.cpp" line="913"/>
        <source>Images (*.png);;</source>
        <translation>Imagenes (*.png);</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="787"/>
        <source>Choose card face image</source>
        <translation>Elije una imagen</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="789"/>
        <location filename="../../DetailedWindow.cpp" line="928"/>
        <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
        <translation>Imagenes (*.png *.jpg *.gif *.jpeg);</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="911"/>
        <source>Choose card back image file</source>
        <translation>Elije una imagen para el reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="926"/>
        <source>Choose card back image</source>
        <translation>Elije una imagen para el reverso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="966"/>
        <source>Are you sure you want to discard changes?</source>
        <translation>¿Está seguro que no quiere guardar los cambios?</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../LoginDialog.cpp" line="97"/>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="105"/>
        <source>Clear</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="149"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="157"/>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="165"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>About Wallet</source>
        <translation>Acerca de Wallet</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="239"/>
        <source>Password is required</source>
        <translation>El password es obligatorio</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="256"/>
        <source>For verification, please, enter your password again</source>
        <translation>Introduzca el password otra vez</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="269"/>
        <source>Invalid password, please enter again</source>
        <translation>Password inválido, introdúzcalo otra vez</translation>
    </message>
</context>
<context>
    <name>RenameGroupDialog</name>
    <message>
        <location filename="../../eWallet.cpp" line="49"/>
        <source>Save &amp;&amp; Close</source>
        <translation>Guardar y Cerrar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="62"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
</context>
<context>
    <name>eWallet</name>
    <message>
        <location filename="../../eWallet.cpp" line="444"/>
        <source>Are you sure you want to remove all your data? You will lost all your data</source>
        <translation>¿Está seguro que quiere borrar todos los datos? Todos los datos que tiene se perderán</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="469"/>
        <source>Wrong password</source>
        <translation>Password incorrecto</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="366"/>
        <location filename="../../eWallet.cpp" line="819"/>
        <source>&lt;All&gt;</source>
        <translation>&lt;Todos&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="385"/>
        <location filename="../../eWallet.cpp" line="828"/>
        <source>&lt;No Group&gt;</source>
        <translation>&lt;Sin Grupo&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="529"/>
        <source>Organization</source>
        <translation>Organización</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="530"/>
        <location filename="../../eWallet.cpp" line="551"/>
        <location filename="../../eWallet.cpp" line="601"/>
        <source>Phone Number</source>
        <translation>Número móvil</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="531"/>
        <location filename="../../eWallet.cpp" line="565"/>
        <source>Other Information</source>
        <translation>Otra información</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="532"/>
        <location filename="../../eWallet.cpp" line="541"/>
        <location filename="../../eWallet.cpp" line="643"/>
        <source>User Name</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="533"/>
        <location filename="../../eWallet.cpp" line="542"/>
        <location filename="../../eWallet.cpp" line="569"/>
        <location filename="../../eWallet.cpp" line="600"/>
        <location filename="../../eWallet.cpp" line="629"/>
        <location filename="../../eWallet.cpp" line="640"/>
        <location filename="../../eWallet.cpp" line="644"/>
        <location filename="../../eWallet.cpp" line="653"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="534"/>
        <source>Organization club</source>
        <translation>Club</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="535"/>
        <location filename="../../eWallet.cpp" line="568"/>
        <location filename="../../eWallet.cpp" line="634"/>
        <source>ID Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="536"/>
        <location filename="../../eWallet.cpp" line="543"/>
        <location filename="../../eWallet.cpp" line="608"/>
        <location filename="../../eWallet.cpp" line="627"/>
        <location filename="../../eWallet.cpp" line="652"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="537"/>
        <location filename="../../eWallet.cpp" line="557"/>
        <location filename="../../eWallet.cpp" line="571"/>
        <location filename="../../eWallet.cpp" line="646"/>
        <location filename="../../eWallet.cpp" line="656"/>
        <source>Card Notes</source>
        <translation>Notas</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="540"/>
        <location filename="../../eWallet.cpp" line="645"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="546"/>
        <source>Credit Card Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="547"/>
        <source>Card Provider</source>
        <translation>Proveedor</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="548"/>
        <source>Card Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="549"/>
        <location filename="../../eWallet.cpp" line="554"/>
        <location filename="../../eWallet.cpp" line="651"/>
        <source>Expiration Date</source>
        <translation>Fecha expiración</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="550"/>
        <source>Name on Card</source>
        <translation>Nombre en la tarjeta</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="552"/>
        <location filename="../../eWallet.cpp" line="563"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="553"/>
        <source>Start Date</source>
        <translation>Fecha inicio</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="555"/>
        <source>Detail</source>
        <translation>Detalle</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="556"/>
        <source>3-digit CVC#</source>
        <translation>CVC</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="560"/>
        <source>Bank Name</source>
        <translation>Nombre banco</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="561"/>
        <source>Account Number</source>
        <translation>Número de cuenta</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="562"/>
        <source>Telephone</source>
        <translation>Teléfono</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="564"/>
        <source>SWIFT Code</source>
        <translation>código SWIFT</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="570"/>
        <location filename="../../eWallet.cpp" line="635"/>
        <source>Card Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="574"/>
        <source>Passport No</source>
        <translation>Número pasaporte</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="575"/>
        <source>Surname</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="576"/>
        <source>Given names</source>
        <translation>Apellidos</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="577"/>
        <source>Date of birth</source>
        <translation>Fecha nacimiento</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="578"/>
        <source>Date of issue</source>
        <translation>Fecha emisión</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="579"/>
        <source>Date of expiration</source>
        <translation>Fecha caducidad</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="580"/>
        <source>Authority</source>
        <translation>Autoridad</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="583"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="586"/>
        <location filename="../../eWallet.cpp" line="590"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="587"/>
        <source>Vehicle Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="591"/>
        <source>Brand</source>
        <translation>Marca</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="592"/>
        <source>IMEI#</source>
        <translation>IMEI</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="593"/>
        <source>Firmware code</source>
        <translation>Firmware code</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="594"/>
        <source>Purchased</source>
        <translation>Comprado en</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="595"/>
        <source>Pin1</source>
        <translation>Pin 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="596"/>
        <source>Pin2</source>
        <translation>Pin 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="597"/>
        <source>Puk1</source>
        <translation>Puk 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="598"/>
        <source>Puk2</source>
        <translation>Puk 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="599"/>
        <source>Num SIM</source>
        <translation>Número SIM</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="602"/>
        <source>Manufacturer</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="605"/>
        <location filename="../../eWallet.cpp" line="619"/>
        <source>Product</source>
        <translation>Producto</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="606"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="607"/>
        <location filename="../../eWallet.cpp" line="620"/>
        <source>Serial #</source>
        <translation>Número de serie</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="609"/>
        <source>Company</source>
        <translation>Compañía</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="610"/>
        <source>Date bought</source>
        <translation>Fecha de compra</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="611"/>
        <source>Username</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="612"/>
        <location filename="../../eWallet.cpp" line="628"/>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="613"/>
        <source>Authorization key</source>
        <translation>Clave autorización</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="614"/>
        <location filename="../../eWallet.cpp" line="623"/>
        <source>Price paid</source>
        <translation>Precio compra</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="615"/>
        <source>Support</source>
        <translation>Soporte</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="616"/>
        <location filename="../../eWallet.cpp" line="631"/>
        <source>Notes</source>
        <translation>Notas</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="621"/>
        <source>Model #</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="622"/>
        <source>Bought from</source>
        <translation>Comprado en</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="624"/>
        <source>Guarantee period</source>
        <translation>Periodo de garantía</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="630"/>
        <source>E mail used</source>
        <translation>Email</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="638"/>
        <source>Social Security Number</source>
        <translation>Número Seguridad social</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="639"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="649"/>
        <source>Driver&apos;s License Number</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="650"/>
        <source>Date Issued</source>
        <translation>Fecha emisión</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="908"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="910"/>
        <source>Delete DB</source>
        <translation>Borrar DB</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="912"/>
        <location filename="../../eWallet.cpp" line="923"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="915"/>
        <source>New</source>
        <translation>Nueva</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="917"/>
        <location filename="../../eWallet.cpp" line="1391"/>
        <source>Edit</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="918"/>
        <source>Invert Sort</source>
        <translation>Invertir el orden</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="919"/>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="920"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="922"/>
        <source>Change Password</source>
        <translation>Cambiar Password</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="982"/>
        <source>Are you sure you want to remove it?</source>
        <translation>¿Está seguro que quiere borrar la tarjeta?</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1130"/>
        <source>Choose import file</source>
        <translation>Elije un fichero a importar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1132"/>
        <location filename="../../eWallet.cpp" line="1407"/>
        <source>Text files (*.txt);;</source>
        <translation>Archivos de texto (*.txt);</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1380"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1381"/>
        <location filename="../../eWallet.cpp" line="1394"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1390"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1392"/>
        <source>New like this</source>
        <translation>Nueva como esta</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1393"/>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1405"/>
        <source>Choose export file</source>
        <translation>Elije el fichero de exportación</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1610"/>
        <source>About Wallet</source>
        <translation>Acerca de Wallet</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1645"/>
        <source>Changing password, please wait until application quits</source>
        <translation>Cambiando el password, espere hasta que la aplicación finalice</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1651"/>
        <source>Password changed successfully, application will exit</source>
        <translation>Password cambiado. La aplicación finalizará sola</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1653"/>
        <source>Password CANNOT BE changed, because %1, and application will exit</source>
        <translation>No se puede cambiar el password por %1, y la applicación finalizará sola</translation>
    </message>
</context>
</TS>
